From 1d516fb17442af9f3b10c0dc605202fc0e286e2d 2010-10-26 08:41:39
From: Erik Tollerud <erik.tollerud@gmail.com>
Date: 2010-10-26 08:41:39
Subject: [PATCH] docstring fix in CloseEvent to conform to standards

---

diff --git a/IPython/frontend/qt/console/ipythonqt.py b/IPython/frontend/qt/console/ipythonqt.py
index a243fbc..c350f2b 100644
--- a/IPython/frontend/qt/console/ipythonqt.py
+++ b/IPython/frontend/qt/console/ipythonqt.py
@@ -58,8 +58,11 @@ class MainWindow(QtGui.QMainWindow):
     #---------------------------------------------------------------------------
     
     def closeEvent(self, event):
-        """ Reimplemented to prompt the user and close the kernel cleanly, or 
-        close without prompt only if the exit magic is used.
+        """ Close the window and the kernel (if necessary).
+        
+        This will prompt the user if they are finished with the kernel, and if
+        so, closes the kernel cleanly. Alternatively, if the exit magic is used,
+        it closes without prompt.
         """
         keepkernel = None #Use the prompt by default
         if hasattr(self._frontend,'_keep_kernel_on_exit'): #set by exit magic